@@ -119,6 +119,8 @@ def parse_comments(issues):
     """
 
     exploded_df = issues.explode("discussion").rename(columns={"discussion": "comment"})
+    valid_comments = exploded_df["comment"].apply(lambda x: isinstance(x, dict))
+    exploded_df = exploded_df[valid_comments]
     commenter_df = pd.DataFrame(exploded_df["comment"].to_list())
     commenter_df.reset_index(inplace=True)
     return commenter_df
@@ -153,9 +155,9 @@ def _get_issues_edge_list(dataframe, author_col_name, discussion_col_name):
 
     edge_list = pd.DataFrame(edges, columns=["source", "target"])
     edge_list = edge_list.groupby(["source", "target"]).size().reset_index(name="weight")
-    
+
     return edge_list
-    
+
 
 def _get_edge_list(dataframe, author_col_name, target_col_name, source_col_name=None):
     """
@@ -204,7 +206,7 @@ def _get_edge_list(dataframe, author_col_name, target_col_name, source_col_name=
         )
     else:
         edge_list = edge_list.reindex(edge_list.columns.tolist() + ["weight"], axis=1)
-        
+
     return edge_list
 
 
@@ -234,7 +236,7 @@ def activity(dataframe, id_col_name, author_col_name, date_col_name):
 
     dataframe[date_col_name] = dataframe[date_col_name].apply(lambda x: datetime(year=x.year, month=x.month, day=x.day))
 
-    start_dates = dataframe.groupby(author_col_name)[author_col_name, date_col_name].min()
+    start_dates = dataframe.groupby(author_col_name)[[author_col_name, date_col_name]].min()
     start_dates.index.name = "author_name_index"
     authors = (
         start_dates.sort_values([date_col_name, author_col_name], ascending=False).loc[:, author_col_name].tolist()
